@@ -2,7 +2,7 @@ package Data::Money::Types;
 
 use MooseX::Types -declare => [ qw(Amount CurrencyCode DataMoney Format) ];
 
-use MooseX::Types::Moose qw(Num Str);
+use MooseX::Types::Moose qw(Num Str Undef);
 use Locale::Currency qw(code2currency);
 
 class_type Amount, { class => 'Math::BigFloat' };
@@ -17,6 +17,7 @@ coerce Amount,
     via {
         # strip out formatting characters
         $_ =~ tr/-()0-9.//cd;
+        $_ = 0 unless($_);
         Math::BigFloat->new($_)
     };
 
@@ -24,6 +25,10 @@ coerce Amount,
     from DataMoney,
     via { Math::BigFloat->new($_->value) };
 
+coerce Amount,
+    from Undef,
+    via { Math::BigFloat->new(0) };
+
 subtype CurrencyCode,
     as Str,
     where { !defined($_) || ($_ =~ /^[A-Z]{3}$/ && defined(code2currency($_))) },
